diff -ur /stuff/pkgsrc/emulators/openmsx/work/openMSX-RELEASE_17_0//build/cpu.py ./build/cpu.py
--- /stuff/pkgsrc/emulators/openmsx/work/openMSX-RELEASE_17_0//build/cpu.py	Tue May 18 20:28:24 2021
+++ ./build/cpu.py	Sun Apr 27 19:46:04 2025
@@ -121,6 +121,13 @@
 	name = 'sparc'
 	bigEndian = True
 
+class Sparc64(CPU):
+	'''Sun Sparc 64.
+	'''
+	name = 'sparc64'
+	bigEndian = True
+	gccFlags = '-m64',
+
 class X86(CPU):
 	'''32-bit x86: Intel Pentium, AMD Athlon etc.
 	'''
diff -ur /stuff/pkgsrc/emulators/openmsx/work/openMSX-RELEASE_17_0//src/file/foreach_file.hh ./src/file/foreach_file.hh
--- /stuff/pkgsrc/emulators/openmsx/work/openMSX-RELEASE_17_0//src/file/foreach_file.hh	Tue May 18 20:28:24 2021
+++ ./src/file/foreach_file.hh	Sun Apr 27 20:43:05 2025
@@ -8,6 +8,10 @@
 #include <functional>
 #include <string_view>
 #include <tuple>
+#include <sys/stat.h>  // Needed for stat() and S_ISREG/S_ISDIR
+#include <unistd.h>    // Needed for access()
+#include <cstring>     // Needed for strerror()
+#include <cerrno>      // Needed for errno
 
 /** This file implemented 3 utility functions:
  *  - foreach_file              (path, fileAction)
@@ -46,6 +50,12 @@
  *  - false: some action requested an abort.
  */
 
+#ifndef DT_UNKNOWN
+#define DT_UNKNOWN 0
+#define DT_REG 8
+#define DT_DIR 4
+#endif
+
 namespace openmsx {
 	namespace detail {
 		using namespace FileOperations;
@@ -111,11 +121,28 @@
 				if (f == one_of(".", "..")) continue;
 				path += f;
 				auto file = std::string_view(path).substr(origLen);
-
-				// When the action is not interested in 'Stat' and on operation systems
-				// that support it: avoid doing an extra 'stat()' system call.
-				auto type = needStat ? static_cast<unsigned char>(DT_UNKNOWN) : d->d_type;
 				Stat st;
+				unsigned char type;
+		
+		#ifdef __sun
+				// Solaris doesn't have d_type, so always call stat()
+				if (stat(path.c_str(), &st) == 0) {
+					if (S_ISREG(st.st_mode)) {
+						type = DT_REG;
+					} else if (S_ISDIR(st.st_mode)) {
+						type = DT_DIR;
+					} else {
+						type = DT_UNKNOWN;
+					}
+				} else {
+					// If stat() fails, assume unknown type
+					type = DT_UNKNOWN;
+				}
+		#else
+				// Use d_type when available
+				type = needStat ? static_cast<unsigned char>(DT_UNKNOWN) : d->d_type;
+		#endif
+		
 				if (type == DT_REG) {
 					if (!invokeFileAction(path, file, st)) {
 						return false; // aborted
@@ -125,6 +152,7 @@
 						return false;
 					}
 				} else {
+					// If type is unknown, fall back to stat()
 					if (getStat(path, st)) {
 						if (isRegularFile(st)) {
 							if (!invokeFileAction(path, file, st)) {
diff -ur /stuff/pkgsrc/emulators/openmsx/work/openMSX-RELEASE_17_0//src/utils/cstd.hh ./src/utils/cstd.hh
--- /stuff/pkgsrc/emulators/openmsx/work/openMSX-RELEASE_17_0//src/utils/cstd.hh	Tue May 18 20:28:24 2021
+++ ./src/utils/cstd.hh	Sun Apr 27 19:46:08 2025
@@ -136,7 +136,7 @@
 template<int>      [[nodiscard]] constexpr double sin  (double x) { return std::sin  (x); }
 template<int>      [[nodiscard]] constexpr double cos  (double x) { return std::cos  (x); }
 template<int, int> [[nodiscard]] constexpr double log  (double x) { return std::log  (x); }
-template<int, int> [[nodiscard]] constexpr double log2 (double x) { return    ::log  (x) / ::log(2); } // should be std::log2(x) but this doesn't seem to compile in g++-4.8/g++-4.9 (bug?)
+template<int, int> [[nodiscard]] constexpr double log2 (double x) { return    ::log  (x) / ::log(2.0); } // should be std::log2(x) but this doesn't seem to compile in g++-4.8/g++-4.9 (bug?)
 template<int, int> [[nodiscard]] constexpr double log10(double x) { return std::log10(x); }
 template<int>      [[nodiscard]] constexpr double exp  (double x) { return std::exp  (x); }
 template<int>      [[nodiscard]] constexpr double exp2 (double x) { return    ::exp2 (x); } // see log2, but apparently no need to use exp(log(2) * x) here?!
